<?php
/**
 * Registering meta boxes
 *
 * All the definitions of meta boxes are listed below with comments.
 * Please read them CAREFULLY.
 *
 * You also should read the changelog to know what has been changed before updating.
 *
 * For more information, please visit:
 * @link http://metabox.io/docs/registering-meta-boxes/
 */
add_filter( 'rwmb_meta_boxes', 'snsanton_register_meta_boxes' );
/**
 * Register meta boxes
 *
 * Remember to change "your_prefix" to actual prefix in your project
 *
 * @param array $meta_boxes List of meta boxes
 *
 * @return array
 */
function snsanton_register_meta_boxes( $meta_boxes ){
	/**
	 * prefix of meta keys (optional)
	 * Use underscore (_) at the beginning to make keys hidden
	 * Alt.: You also can make prefix empty to disable it
	 */
	// Better has an underscore as last sign
	$prefix = 'snsanton_';
	global $wpdb, $snsanton_opt;
	$revsliders =array();
	$revsliders[0] = 'Select a slider';
	if ( ! function_exists( 'is_plugin_active' ) ) {
        require_once ABSPATH . 'wp-admin/includes/plugin.php';
    }
	if (is_plugin_active('revslider/revslider.php')) {
		$query = $wpdb->prepare("
			SELECT * 
			FROM {$wpdb->prefix}revslider_sliders 
			ORDER BY %s"
			, "ASC");
	    $get_sliders = $wpdb->get_results($query);
	    if($get_sliders) {
		    foreach($get_sliders as $slider) {
			   $revsliders[$slider->alias] = $slider->title;
		   }
	    }
	}
	//var_dump($get_sliders);
	//
	$default_layout = 'm-r';
	if ( isset($snsanton_opt['blog_layout']) ) $default_layout = $snsanton_opt['blog_layout'];
	//
	$siderbars = array();
	foreach ($GLOBALS['wp_registered_sidebars'] as $sidebars) {
		$siderbars[ $sidebars['id']] = $sidebars['name'];
	}
	// Layout config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_productcfg',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Product Config', 'snsanton' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'product' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields

		'fields'     => array(
			 array(
					'name'    => esc_html__( 'Product Sidebar', 'snsanton' ),
					'id'       => "{$prefix}product_sidebar",
					'type'     => 'select',
					'std'  => '',
					'options'  => array(
						''  => esc_html__( 'Default', 'snsanton' ),
						'0'  => esc_html__( 'No', 'snsanton' ),
						'1'  => esc_html__( 'Yes', 'snsanton' ),
					),
					'desc'		=> esc_html__('Product page with Sidebar. Select "Default" to use in Theme Options.', 'snsanton'),
				),
			  array(
					'name'    => esc_html__( 'Cloud Zoom', 'snsanton' ),
					'id'       => "{$prefix}woo_zoomtype",
					'type'     => 'select',
					'std'  => '',
					'options'  => array(
						''  => esc_html__( 'Default', 'snsanton' ),
						'window'  => esc_html__( 'window', 'snsanton' ),
						'lens'  => esc_html__( 'lens', 'snsanton' ),
						'inner'  => esc_html__( 'Inner', 'snsanton' ),
					),
					'desc'		=> '',
				),
			array(
				'id'    => "{$prefix}product_video",
				'name'  => esc_html__( 'Product Video', 'snsanton' ),
				'type'  => 'oembed',
				// Allow to clone? Default is false
				'clone' => false,
				'desc'		  => esc_html__( 'Enter your video url(youtube, video)', 'snsanton' ),
				// Input size
				'size'  => 50,
			)
		)
	);

	// Layout config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_layout',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Layout Config', 'snsanton' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'page' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields

		'fields'     => array(
			
			array(
				'name'        => esc_html__( 'Config layout for this page', 'snsanton' ),
				'id'          => "{$prefix}enablelayoutconfig",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsanton' ),
					'2' => esc_html__( 'No', 'snsanton' ),
				),
				'std'         => '2',
				'desc'		  => esc_html__( 'Sellect Yes if you want config layout for this page', 'snsanton' ),
			),
			// Layout Type
			array(
				'name'        => esc_html__( 'Layout Type', 'snsanton' ),
				'id'          => "{$prefix}layouttype",
				'type'        => 'layouttype',
				// Array of 'value' => 'Label' pairs for select box
				'options'     => array(
					'm' => esc_html__( 'Without Sidebar', 'snsanton' ),
					'l-m' => esc_html__( 'Use Left Sidebar', 'snsanton' ),
					'm-r' => esc_html__( 'Use Right Sidebar', 'snsanton' ),
					//'l-m-r' => esc_html__( 'Use Left & Right Sidebar', 'snsanton' ),
				),
				// Select multiple values, optional. Default is false.
				'multiple'    => false,
				'std'         => $default_layout,
				'placeholder' => esc_html__( '--- Select a layout type ---', 'snsanton' ),
			),
			// Left Sidebar
			array(
				'name'  => esc_html__( 'Left Sidebar', 'snsanton' ),
				'id'    => "{$prefix}leftsidebar",
				//'desc'  => esc_html__( 'Text description', 'snsanton' ),
				'type'  => 'select',
				'options'	=> $siderbars,
				'multiple'	=> false,
				'std'		=> 'left-sidebar',
				'placeholder' => esc_html__( '--- Select a sidebar ---', 'snsanton' ),
			),
			// Right Sidebar
			array(
				'name'  => esc_html__( 'Right Sidebar', 'snsanton' ),
				'id'    => "{$prefix}rightsidebar",
				//'desc'  => esc_html__( 'Text description', 'snsanton' ),
				'type'  => 'select',
				'options'	=> $siderbars,
				'multiple'	=> false,
				'std'		=> 'right-sidebar',
				'placeholder' => esc_html__( '--- Select a sidebar ---', 'snsanton' ),
			),
			
		)
	);
	
	$menus = get_terms('nav_menu', array( 'hide_empty' => false ));
	$menu_options[''] = __('Default Menu...', 'snsanton');
	foreach ( $menus as $menu ){
		$menu_options[$menu->term_id] = $menu->name;
	}
	
	// Page config
	$meta_boxes[] = array(
		// Meta box id, UNIQUE per meta box. Optional since 4.1.5
		'id'         => 'sns_pageconfig',
		// Meta box title - Will appear at the drag and drop handle bar. Required.
		'title'      => esc_html__( 'Page Config', 'snsanton' ),
		// Post types, accept custom post types as well - DEFAULT is 'post'. Can be array (multiple post types) or string (1 post type). Optional.
		'post_types' => array( 'page' ),
		// Where the meta box appear: normal (default), advanced, side. Optional.
		'context'    => 'normal',
		// Order of meta box: high (default), low. Optional.
		'priority'   => 'high',
		// Auto save: true, false (default). Optional.
		// 'autosave'   => true,
		// List of meta fields

		'fields'     => array(
			array(
				'name'    => esc_html__( 'Margin of body', 'snsanton' ),
				'id'       => "{$prefix}body_margin",
				'type'     => 'text',
				'std'  => '',
			),
			array(
				'name'    => esc_html__( 'Header Style', 'snsanton' ),
				'id'       => "{$prefix}header_style",
				'type'     => 'select',
				'std'  => '',
				'options'  => array(
					''   	  => esc_html__( '', 'snsanton' ),
					'style1'  => esc_html__( 'Style1', 'snsanton' ),
					'style2'  => esc_html__( 'Style2', 'snsanton' ),
					'style3'  => esc_html__( 'Style3', 'snsanton' ),
					'style4'  => esc_html__( 'Style4', 'snsanton' ),
					'style5'  => esc_html__( 'Style5', 'snsanton' ),
					'style6'  => esc_html__( 'Style6', 'snsanton' ),
				),
				'desc'		=> esc_html__('Select Header style. ', 'snsanton'),
			),
            array(
				'name'    => esc_html__( 'Header Background Color', 'snsanton' ),
				'id'       => "{$prefix}header_bg_color",
				'type'     => 'color',		
				'std'         => '',
			),
			array(
				'name'    => esc_html__( 'Use extra screen', 'snsanton' ),
				'id'       => "{$prefix}use_fullwidth",
				'type'     => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsanton' ),
					'2' => esc_html__( 'No', 'snsanton' ),
				),
				'std'         => '2',
				'desc'		=> esc_html__('Select yes if you want to content full-screen', 'snsanton'),
			),
			 array(
			 	'name'    => esc_html__( 'Logo', 'snsanton' ),
			 	'id'       => "{$prefix}header_logo",
		       'type'    => 'image_advanced',
		        'default'	=> '',
		        'desc' => esc_html__( 'It priority more in theme option', 'snsanton' ),	
		    ),
			 array(
				'name' => esc_html__( 'Show Menu', 'snsanton' ),
				'id'   => "{$prefix}enable_menu",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsanton' ),
					'0' => esc_html__( 'No', 'snsanton' ),
				),
				'std'         => '1',
			),

			array(
				'name'    => esc_html__( 'Show Title', 'snsanton' ),
				'id'      => "{$prefix}showtitle",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsanton' ),
					'2' => esc_html__( 'No', 'snsanton' ),
				),
				'std'         => '1',
			),
			array(
				'name'    => esc_html__( 'Use Slideshow', 'snsanton' ),
				'id'      => "{$prefix}useslideshow",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsanton' ),
					'2' => esc_html__( 'No', 'snsanton' ),
				),
				'std'         => '2',
			),
			array(
				'name'    => esc_html__( 'Select Slideshow', 'snsanton' ),
				'id'      => "{$prefix}revolutionslider",
				'type'    => 'select',
				'options' =>  $revsliders ,
				'std'         => '',
			),
			array(
				'name'    => esc_html__( 'Show Breadcrumbs', 'snsanton' ),
				'id'      => "{$prefix}showbreadcrump",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsanton' ),
					'2' => esc_html__( 'No', 'snsanton' ),
				),
				'std'         => '1',
				'desc' => esc_html__( 'Dont apply for Front page. Because breadcrumbs dont sense in Front page.', 'snsanton' ),
			),
			array(
				'name'    => esc_html__( 'Custom Background for Breadcrumbs', 'snsanton' ),
				'id'      => "{$prefix}bg_showbreadcrump",
				'type'    => 'image_advanced',
				'default'  => '',
				'desc' => esc_html__( 'It priority more in theme option', 'snsanton' ),			
			),
			// array(
			// 	'name' => esc_html__( 'Body Background', 'snsanton' ),
			// 	'id'   => "{$prefix}body_bg_color",
			// 	'type' => 'color',
			// 	'std'         => '#ffffff',
			// 	'desc' => esc_html__( 'It will priority than Theme Color in Theme Option panel', 'snsanton' ),
			// ),
			array(
				'name'    => esc_html__( 'Config Theme Color for this page?', 'snsanton' ),
				'id'      => "{$prefix}page_themecolor",
				'type'    => 'radio',
				'options' => array(
					'1' => esc_html__( 'Yes', 'snsanton' ),
					'2' => esc_html__( 'No', 'snsanton' ),
				),
				'std'         => '2',
			),
			array(
				'name' => esc_html__( 'Sellect Theme Color', 'snsanton' ),
				'id'   => "{$prefix}theme_color",
				'type' => 'color',
				'desc' => esc_html__( 'It will priority than Theme Color in Theme Option panel', 'snsanton' ),
			),
			array(
				'name'    => esc_html__( 'Footer Layout', 'snsanton' ),
				'id'       => "{$prefix}footer_layout",
				'type'     => 'select',
				'std'  => '',
				'options'  => array(
					''  => esc_html__( 'Default', 'snsanton' ),
					'layout_1'  => esc_html__( 'Layout 1', 'snsanton' ),
					'layout_2'  => esc_html__( 'Layout 2', 'snsanton' ),
					'layout_3'  => esc_html__( 'Layout 3', 'snsanton' ),
					'layout_4'  => esc_html__( 'Layout 4', 'snsanton' ),
					'layout_5'  => esc_html__( 'Layout 5', 'snsanton' ),
					'layout_6'  => esc_html__( 'Layout 6', 'snsanton' ),
				),
				'desc'		=> esc_html__('Select Footer layout. "Default" to use in Theme Options.', 'snsanton'),
			),
			array(
				'name'    => esc_html__( 'Footer bottom background color', 'snsanton' ),
				'id'       => "{$prefix}footer_bottom_bg_color",
				'type'     => 'color',
			),
			array(
				'name'    => esc_html__( 'Payment image', 'snsanton' ),
				'id'       => "{$prefix}payment_img",
				'type'     => 'image_advanced',
			),
		)
	);
	// Post format - Gallery
	$meta_boxes[] = array(
	    	'id' => 'sns-post-gallery',
		    'title' =>  esc_html__('Gallery Settings','snsanton'),
	    	'description' => '',
    		'pages'      => array( 'post' ), // Post type
	    	'context'    => 'normal',
		    'priority'   => 'high',
	    	'fields' => array(
			     array(
			        'name'		=> 'Gallery Images',
			        'desc'	    => 'Upload Images for post Gallery ( Limit is 15 Images ).',
			        'type'      => 'image_advanced',
			        'id'	    => "{$prefix}post_gallery",
	         		'max_file_uploads' => 15 
	        	)
			)
	);
	// Post format - Video
    $meta_boxes[] = array(
		'id' => 'sns-post-video',
		'title' => esc_html__('Featured Video','snsanton'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_video",
				'name'  => esc_html__( 'Video', 'snsanton' ),
				'type'  => 'oembed',
				// Allow to clone? Default is false
				'clone' => false,
				// Input size
				'size'  => 50,
			)
		)
	);
	// Post format - Audio
    $meta_boxes[] = array(
		'id' => 'sns-post-audio',
		'title' => esc_html__('Featured Audio','snsanton'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_audio",
				'name'  => esc_html__( 'Audio', 'snsanton' ),
				'type'  => 'oembed',
				// Allow to clone? Default is false
				'clone' => false,
				// Input size
				'size'  => 50,
			)
		)
	);
	// Post format - quote
    $meta_boxes[] = array(
		'id' => 'sns-post-quote',
		'title' => esc_html__('Featured Quote','snsanton'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_quotecontent",
				'name'  => esc_html__( 'Quote Content', 'snsanton' ),
				'type'  => 'textarea',
				// Allow to clone? Default is false
				'clone' => false,
			),
			array(
				'id'      => "{$prefix}post_quoteauthor",
				'name'    => esc_html__( 'Quote author', 'snsanton' ),
				'type'    => 'text',
				'clone' => false,
			),
			array(
				'id'      => "{$prefix}post_quote_bg",
				'name'    => esc_html__( 'Quote Background Color', 'snsanton' ),
				'type'    => 'color',
				'std'         => '#ffffff',
			),
			array(
				'id'      => "{$prefix}post_quote_color",
				'name'    => esc_html__( 'Quote Text Color', 'snsanton' ),
				'type'    => 'color',
				'std'         => '#888888',
			),
			array(
				'id'      => "{$prefix}post_quote_size",
				'name'    => esc_html__( 'Quote Text Size', 'snsanton' ),
				'type'    => 'text',
				'std'         => '16px',
			),
			array(
				'id'      => "{$prefix}post_quote_font_weight",
				'name'    => esc_html__( 'Quote Text Weight', 'snsanton' ),
				'type'     => 'select',
				'std'  => '400',
				'options'  => array(
					'100'  => esc_html__( '100', 'snsanton' ),
					'200'  => esc_html__( '200', 'snsanton' ),
					'300'  => esc_html__( '300', 'snsanton' ),
					'400'  => esc_html__( '400', 'snsanton' ),
					'500'  => esc_html__( '500', 'snsanton' ),
					'600'  => esc_html__( '600', 'snsanton' ),
					'700'  => esc_html__( '700', 'snsanton' ),
					'900'  => esc_html__( '900', 'snsanton' ),
				),
			),
		)
	);
	// Post format - Link
    $meta_boxes[] = array(
		'id' => 'sns-post-link',
		'title' => esc_html__('Link Settings','snsanton'),
		'description' => '',
		'pages'      => array( 'post' ), // Post type
		'context'    => 'normal',
		'priority'   => 'high',
		'fields' => array( 
		    array(
				'id'    => "{$prefix}post_linkurl",
				'name'  => esc_html__( 'Link URL', 'snsanton' ),
				'type'  => 'text',
				// Allow to clone? Default is false
				'clone' => false,
			),
			array(
				'id'      => "{$prefix}post_linktitle",
				'name'    => esc_html__( 'Link Title', 'snsanton' ),
				'type'    => 'text',
				'clone' => false,
			),
		)
	);
	// Brand config
	$meta_boxes[] = array(
		'id'         => 'sns_brandconfig',
		'title'      => esc_html__( 'Brand Config', 'snsanton' ),
		'post_types' => array( 'brand' ),
		'context'    => 'normal',
		'priority'   => 'high',
		'fields'     => array(
			array(
				'name'    => esc_html__( 'Link for brand', 'snsanton' ),
				'id'      => "{$prefix}brandlink",
				'type'    => 'text'
			),
		)
	);

	return $meta_boxes;
}


if ( class_exists( 'RWMB_Field' ) ) {
	class RWMB_Layouttype_Field extends RWMB_Select_Field {
		static function admin_enqueue_scripts(){
			wp_enqueue_style( 'sns-imgselect', SNSANTON_THEME_URI . '/framework/meta-box/img-select.css' );
		}
	}
	// Js for metabox fields action
	add_action( 'admin_print_scripts', 'snsanton_metabox_adminjs');
    function snsanton_metabox_adminjs(){
		wp_enqueue_script('sns-imgselect', SNSANTON_THEME_URI . '/framework/meta-box/sns-metabox.js', array('jquery'), '', true);
	}
}
