<?php
define( 'SNSANTON_THEME_DIR', get_template_directory() );
define( 'SNSANTON_THEME_URI', get_template_directory_uri() );

// Require framework
require_once( SNSANTON_THEME_DIR.'/framework/init.php' );
/** 
 *   Initialize Visual Composer in the theme.
 **/
add_action( 'vc_before_init', 'snsanton_vcSetAsTheme' );
function snsanton_vcSetAsTheme() {
	vc_set_as_theme(true);
}
// Initialising Visual shortcode editor
 if (class_exists('WPBakeryVisualComposerAbstract')) {
 	function snsanton_requireVcExtend(){
 		include_once( SNSANTON_THEME_DIR . '/vc_extend/extend-vc.php' );
 	}
 	add_action('init', 'snsanton_requireVcExtend', 2);
 }
/** 
 *	Width of content, it's max width of content without sidebar.
 **/
if ( ! isset( $content_width ) ) { $content_width = 660; }
add_filter( 'woocommerce_redirect_single_search_result', '__return_false' );
/** 
 *	Set base function for theme.
 **/
if ( ! function_exists( 'snsanton_setup' ) ) {
    function snsanton_setup() {
        global $snsanton_opt, $snsanton_obj;
    	// Load default theme textdomain.
        load_theme_textdomain( 'snsanton' , SNSANTON_THEME_DIR . '/languages' );
		// Add default posts and comments RSS feed links to head.
        add_theme_support( 'automatic-feed-links' );
		// Enable support for Post Thumbnails on posts and pages.
        add_theme_support( 'post-thumbnails' );
        // Add title-tag, it auto title of head
        add_theme_support( 'title-tag' );
        // Enable support for Post Formats.
        add_theme_support( 'post-formats',
            array(
                'video', 'audio', 'quote', 'link', 'gallery'
            )
        );
        // Register images size
        add_image_size('snsanton_megamenu_thumb', 250, 150, true);
        add_image_size('snsanton_blog_layout2_thumbnail_size', 720,404, true); // blog layout 2
        add_image_size('snsanton_latest_posts_thumbnail_size', 600,337, true); // blog layout 2
        add_image_size('snsanton_latest_posts', 555, 312, true);
        add_image_size('snsanton_latest_posts_widget', 80, 53, true);
        add_image_size('snsanton_testimonial_avatar', 120, 120, true);
        add_image_size('snsanton_products_slider_thumb', 680, 530, false);
        add_image_size('snsanton_thumbnail_size', 70, 70, true);
        add_image_size('snsanton_product_sc_image_size', 670, 670, true);
        add_image_size('snsanton_product_thumbnail_size', 170, 240, true);
        add_image_size('snsanton_single_product_size', 800 , 800, true);
        add_image_size('snsanton_attribute_pa_images_size', 64, 64, false);
        
		//Setup the WordPress core custom background & custom header feature.
         $default_background = array(
            'default-color' => '#FFF',
        );
        add_theme_support( 'custom-background', $default_background );
        $default_header = array();
        add_theme_support( 'custom-header', $default_header );
        // Register navigations
	    register_nav_menus( array(
			'main_navigation' => esc_html__( 'Main navigation', 'snsanton' ),
            'top_navigation'  => esc_html__( 'Top navigation', 'snsanton' ),
            'bottom_navigation'  => esc_html__( 'Bottom navigation', 'snsanton' ),
            'vertical_navigation' => esc_html__( 'Vertical navigation', 'snsanton' ),
		) );
    }
    add_action ( 'after_setup_theme', 'snsanton_setup' );
}
add_action( 'after_setup_theme', 'snsanton_woocommerce_support' );
function snsanton_woocommerce_support() {
    add_theme_support( 'woocommerce' );
}

/** 
    Add class for body
 **/
add_filter( 'body_class', 'snsanton_bodyclass' );
function snsanton_bodyclass( $classes ) {
    if ( snsanton_themeoption('use_boxedlayout', 0) == 1) {
        $classes[] = 'boxed-layout';
    }
    if( snsanton_themeoption('advance_tooltip', 1) == 1){
        $classes[] = 'use-tooltip';
    }
    if( snsanton_themeoption('use_stickmenu') == 1){
        $classes[] = 'use_stickmenu';
    }
    if ( snsanton_themeoption('woo_uselazyload') == 1 ){
        $classes[] = 'use_lazyload';
    }

    if( snsanton_themeoption('use_fullwidth') ==1 && snsanton_themeoption('use_boxedlayout', 0) == 0){
        $classes[] = 'fullwidth';
    }
    if(class_exists('WooCommerce')){
        $classes[] = 'woocommerce';
        $woo_onsale_layout = snsanton_themeoption('woo_onsale_layout', 'carousel');
        if(is_product_category()){
            $cate = get_queried_object();
            $woo_onsale_layout = snsanton_get_term_byid($cate->term_id, 'snsanton_woo_onsale_layout');
        }
        if( $woo_onsale_layout != '' ){
            $classes[] = 'sns-archive-product-onsale-'.$woo_onsale_layout;
        }
    }

    return $classes;
}

function snsanton_widgetlocations(){
    // Register widgetized locations
    if(function_exists('register_sidebar')) {
        register_sidebar(array(
           'name' => esc_html__( 'Widget Area','snsanton' ),
           'id'   => 'widget-area',
            'description'   => esc_html__( 'These are widgets for the Widget Area.','snsanton' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));

         register_sidebar(array(
           'name' => esc_html__( 'Contact Us','snsanton' ),
           'id'   => 'contact_us',
            'description'   => esc_html__( 'This widget in Footer','snsanton' ),
            'before_widget' => '<div class="widget %2$s contact_us">',
            'after_widget'  => '</div>', 
        ));
        register_sidebar(array(
	        'name' => esc_html__( 'Menu Sidebar #1','snsanton' ),
	        'id'   => 'menu_sidebar_1',
	        'description'   => esc_html__( 'These are widgets for Mega Menu Columns style. This sidebar displayed in the left of column.','snsanton' ),
	        'before_widget' => '<div class="widget sidebar-menu-widget %2$s">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h4 class="hide">',
	        'after_title'   => '</h4>'
        ));
        
        register_sidebar(array(
	        'name' => esc_html__( 'Menu Sidebar #2','snsanton' ),
	        'id'   => 'menu_sidebar_2',
	        'description'   => esc_html__( 'These are widgets for Mega Menu Columns style. This sidebar displayed in the right of column.','snsanton' ),
	        'before_widget' => '<div class="widget sidebar-menu-widget %2$s">',
	        'after_widget'  => '</div>',
	        'before_title'  => '<h4 class="hide">',
	        'after_title'   => '</h4>'
        ));
        register_sidebar(array(
           'name' => esc_html__( 'Header Top Left','snsanton' ),
           'id'   => 'header-top-left',
            'description'   => esc_html__( 'Used for Header Top Left','snsanton' ),
            'before_widget' => '<div id="%1$s" class="widget header-top-left %2$s">',       
            'after_widget'  => '</div>',
        ));  
         register_sidebar(array(
           'name' => esc_html__( 'Header Top Right','snsanton' ),
           'id'   => 'header-top-right',
            'description'   => esc_html__( 'Used for Header Top Right','snsanton' ),
            'before_widget' => '<div id="%1$s" class="widget header-top-right %2$s">',       
            'after_widget'  => '</div>',
        ));    
         register_sidebar(array(
           'name' => esc_html__( 'Bottom Sidebar','snsanton' ),
           'id'   => 'bottom_sidebar',
            'description'   => esc_html__( 'Used for footter top','snsanton' ),
            'before_widget' => '<div id="%1$s" class="widget bottom-sidebar %2$s col-md-12">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>'
        )); 
      
        register_sidebar(array(
           'name' => esc_html__( 'Footer Box #1','snsanton' ),
           'id'   => 'footer-box-1',
            'description'   => esc_html__( 'These are widgets for Footer Box #1','snsanton' ),
            'before_widget' => '<div id="%1$s" class="widget footer_box_1 %2$s">',       
            'after_widget'  => '</div>',
        ));
         register_sidebar(array(
           'name' => esc_html__( 'Footer Box #2','snsanton' ),
           'id'   => 'footer-box-2',
            'description'   => esc_html__( 'These are widgets for Footer Box #2','snsanton' ),
            'before_widget' => '<div id="%1$s" class="widget footer_bo_2 %2$s">',       
            'after_widget'  => '</div>',
        ));
          register_sidebar(array(
           'name' => esc_html__( 'Footer Box #3','snsanton' ),
           'id'   => 'footer-box-3',
            'description'   => esc_html__( 'These are widgets for Footer Box #3','snsanton' ),
            'before_widget' => '<div id="%1$s" class="widget footer_box_3 %2$s">',       
            'after_widget'  => '</div>',
        ));
         register_sidebar(
            array(
            'name' => esc_html__( 'Product Sidebar','snsanton' ),
            'id' => 'product-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
        register_sidebar(
            array(
            'name' => esc_html__( 'Woo Sidebar','snsanton' ),
            'id' => 'woo-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
         register_sidebar(
            array(
            'name' => esc_html__( 'Blog Sidebar','snsanton' ),
            'id' => 'blog-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3 class="widget-title"><span>',
            'after_title' => '</span></h3>',
        ));
      
    }
}
add_action( 'widgets_init', 'snsanton_widgetlocations' );
/** 
 *	Add styles & scripts
 **/
function snsanton_scripts() {
	global $snsanton_opt, $snsanton_obj;
    $optimize = ''; //$optimize = '.min';

	// Enqueue style
	$css_file = $snsanton_obj->snsanton_css_file();
	wp_enqueue_style('bootstrap', SNSANTON_THEME_URI . '/assets/css/bootstrap.min.css');
    wp_enqueue_style('owlcarousel', SNSANTON_THEME_URI . '/assets/css/owl.carousel.min.css');
    wp_enqueue_style('tinycarousel', SNSANTON_THEME_URI . '/assets/css/tinycarousel.css');
	wp_enqueue_style('fonts-awesome', SNSANTON_THEME_URI . '/assets/fonts/awesome/css/font-awesome.min.css');
    wp_enqueue_style('fonts-awesome-animation', SNSANTON_THEME_URI . '/assets/fonts/awesome/css/font-awesome-animation.min.css');
    wp_enqueue_style('elegant-font', SNSANTON_THEME_URI . '/assets/fonts/elegant_font/css/elegant-font.min.css');
    wp_enqueue_style('snsanton-ie9', SNSANTON_THEME_URI . '/assets/css/ie9.css');
    wp_enqueue_style('snsanton-woocommerce', SNSANTON_THEME_URI . '/assets/css/woocommerce'.$optimize.'.css');
	wp_enqueue_style('snsanton-theme-style', SNSANTON_THEME_URI . '/assets/css/' . $css_file);
    wp_register_script('tinycarousel', SNSANTON_THEME_URI . '/assets/js/jquery.tinycarousel.min.js', array('jquery'), '', true);
    wp_enqueue_script('tinycarousel');
	wp_register_script('owlcarousel', SNSANTON_THEME_URI . '/assets/js/owl.carousel.min.js', array('jquery'), '', true);
    wp_register_script( 'waypoints' , SNSANTON_THEME_URI . '/assets/js/waypoints.min.js', array('jquery'), '', true);
    wp_enqueue_script('owlcarousel');
	wp_register_script('masonry', SNSANTON_THEME_URI . '/assets/js/masonry.pkgd.min.js', array('jquery'), '', true);
	wp_register_script('imagesloaded', SNSANTON_THEME_URI . '/assets/js/imagesloaded.pkgd.min.js', array('jquery'), '', true);
	wp_register_script('countdown', SNSANTON_THEME_URI . '/assets/countdown/jquery.countdown.min.js', array('jquery'), '2.1.0', true);
    // Enqueue script
    wp_enqueue_script('bootstrap', SNSANTON_THEME_URI . '/assets/js/bootstrap.min.js', array('jquery'), '', true);
    wp_enqueue_script('bootstrap-tabdrop', SNSANTON_THEME_URI . '/assets/js/bootstrap-tabdrop.min.js', array('jquery'), '', true);
    if( snsanton_themeoption('woo_uselazyload') == 1 ) wp_enqueue_script('lazyload', SNSANTON_THEME_URI . '/assets/js/jquery.lazyload'.$optimize.'.js', array(), '', true);
    wp_enqueue_script('snsanton-script', SNSANTON_THEME_URI . '/assets/js/sns-script'.$optimize.'.js', array('jquery'), '', true);
   
    // IE
    wp_enqueue_script('html5shiv', SNSANTON_THEME_URI . '/assets/js/html5shiv.min.js', array('jquery'), '');
    wp_script_add_data('html5shiv', 'conditional', 'lt IE 9');
    wp_enqueue_script('respond', SNSANTON_THEME_URI . '/assets/js/respond.min.js', array('jquery'), '');
    wp_script_add_data('respond', 'conditional', 'lt IE 9');
    // Add style inline with option in admin theme option
    wp_add_inline_style('snsanton-theme-style', snsanton_cssinline());
    // Add inline scritp
    wp_add_inline_script('snsanton-script', snsanton_jsinline());
    // Code to embed the javascript file that makes the Ajax request
    wp_enqueue_script('ajax-request', SNSANTON_THEME_URI . '/assets/js/ajax.js', array('jquery'));
    // Code to declare the URL to the file handing the AJAX request
    $js_params = array(
    	'ajaxurl' => admin_url( 'admin-ajax.php' )
    );
    global $wp_query, $wp;
    $js_params['query_vars'] = $wp_query->query_vars;
    $js_params['current_url'] = esc_url(home_url($wp->request));
    
    wp_localize_script('ajax-request', 'sns', $js_params);
    
}
add_action( 'wp_enqueue_scripts', 'snsanton_scripts' );

/*
 * Enqueue admin styles and scripts
 */
function snsanton_admin_styles_scripts(){
	wp_enqueue_style('snsanton_admin_style', SNSANTON_THEME_URI.'/admin/assets/css/admin-style.css');
	wp_enqueue_style( 'wp-color-picker' );
	
	wp_enqueue_media();
	wp_enqueue_script( 'wp-color-picker' );
	wp_enqueue_script('snsanton_admin_template_js', SNSANTON_THEME_URI.'/admin/assets/js/admin_template.js', array( 'jquery', 'wp-color-picker' ), false, true);
}
add_action('admin_enqueue_scripts', 'snsanton_admin_styles_scripts');

// Editor style
add_editor_style('assets/css/editor-style.css');
/**
 * CSS inline
**/
function snsanton_cssinline(){
    global $snsanton_opt;
    $inline_css = '';
    // Body style
    $bodycss = '';
   // $body_bg_color = '';
    if (snsanton_getOption('use_boxedlayout') == 1) {
        if ($snsanton_opt['body_bg_type'] == 'pantern') {
            $bodycss .= 'background-image: url('.SNSANTON_THEME_URI.'/assets/img/patterns/'.$snsanton_opt['body_bg_type_pantern'].');';
        }elseif( $snsanton_opt['body_bg_type'] == 'img' ){
            $bodycss .= 'background-image: url('.$snsanton_opt['body_bg_type_img']['url'].');';
        }
    }
    if(isset($snsanton_opt['body_font']) && is_array($snsanton_opt['body_font'])) {
        $body_font = '';
        foreach($snsanton_opt['body_font'] as $propety => $value)
            if($value != 'true' && $value != 'false' && $value != '' && $propety != 'subsets')
                $body_font .= $propety . ':' . $value . ';';
        
        if($body_font != '') $bodycss .= $body_font;
    }
    $inline_css .= 'body {'.$bodycss.'}';
    // Selectors use google font
    if(isset($snsanton_opt['secondary_font_target']) && $snsanton_opt['secondary_font_target']) {
        if(isset($snsanton_opt['secondary_font']) && is_array($snsanton_opt['secondary_font'])) {
            $secondary_font = '';
            foreach($snsanton_opt['secondary_font'] as $propety => $value)
                if($value != 'true' && $value != 'false' && $value != '' && $propety != 'subsets')
                    $secondary_font .= $propety . ':' . $value . ';';
            
            if($secondary_font != '') $inline_css .= $snsanton_opt['secondary_font_target'] . ' {'.$secondary_font.'}';
        }
    }
    //
    $body_mgr = snsanton_themeoption('body_margin');
    if( $body_mgr != '0px' && $body_mgr != '' ){
        $inline_css .= '
            #sns_wrapper{ margin:'.$body_mgr.'; }
            @media(max-width: 1199px){
                #sns_wrapper .container{ width: auto; }
            }
            @media(max-width: 480px){
                #sns_wrapper .container{ padding: 0 0; }
            }
        ';
    }
    // Breadcrumbs
    $showbreadcrumbs = 1;
    $bg_url = '';
    $bg_showbreadcrump = snsanton_getOption('bg_showbreadcrump');
    if( is_array($bg_showbreadcrump) ) {
        foreach ($bg_showbreadcrump as $key => $value) {
            if ( isset( $value['full_url'] ) ) {
                $bg_url = $value['full_url'];
            } else {
                $bg_showbreadcrump = snsanton_getOption('bg_showbreadcrump');
                $bg_url = $bg_showbreadcrump['url'];
            }                           
        }
    }       
    if ( get_post_type( get_the_ID() ) == 'page' ) :
        if ( is_front_page() || ( snsanton_metabox('snsanton_showbreadcrump') == '2' ) ) :
            $showbreadcrumbs = 0;
        endif;
    elseif ( get_post_type( get_the_ID() ) == 'post') :
            $showbreadcrumbs = 1;
    endif;
    if( $showbreadcrumbs == '1' || rwmb_meta('snsanton_showtitle') == 1 ) {
        $inline_css .= ' #sns_breadcrumbs {';
        if ( esc_attr($bg_url) ) {
            $inline_css .= '
            background-image:url('.esc_attr($bg_url).');
            background-position: center top;
            background-repeat: no-repeat;
            ';
        }else{
            $inline_css .= 'background-color: #888888;';
        }
        $inline_css .= ' 
            min-height:200px; 
        }'; 
    }
    // advance customcss
    if(isset($snsanton_opt['advance_customcss']) && $snsanton_opt['advance_customcss']) {
        $inline_css .= $snsanton_opt['advance_customcss'];
    }
    return $inline_css;
}

/* 
 * Add tpl footer
 */
function snsanton_tplfooter() {
    $output = '';
    ob_start();
    require SNSANTON_THEME_DIR . '/tpl-footer.php';
    $output = ob_get_clean();
    echo $output;
}
add_action('wp_footer', 'snsanton_tplfooter');
/* 
 * Custom js inline and js in admin panel theme
 */
function snsanton_jsinline() {
    // write out custom code
    $output = '';
    ob_start();
    ?>
    jQuery(document).ready(function(){
        <?php if( snsanton_themeoption('tag_showmore', '1') == '1' ): ?>
        if(jQuery('.widget_tag_cloud').length > 0){
            var $tag_display_first  = <?php echo absint( snsanton_themeoption('tag_display_first', 7) ) - 1?>;
            var $number_tags        = jQuery('.widget_tag_cloud .tagcloud a').length;
            var $_this              = jQuery('.widget_tag_cloud .tagcloud');
            var $view_all_tags      = "<?php echo esc_html__('View all tags', 'snsanton');?>";
            var $hide_all_tags      = "<?php echo esc_html__('Hide all tags', 'snsanton');?>";
            
            if( $number_tags > $tag_display_first ){
                jQuery('.widget_tag_cloud .tagcloud a:gt('+$tag_display_first+')').addClass('is_visible').hide();
                jQuery($_this).append('<div class="view-more-tag"><a href="#" title="">'+$view_all_tags+'</a></div>');

                jQuery('.widget_tag_cloud .tagcloud .view-more-tag a').click(function(){
                    if(jQuery(this).hasClass('active')){
                        if( jQuery($_this).find('a').hasClass('is_hidden') ){
                            $_this.find('.is_hidden').removeClass('is_hidden').addClass('is_visible').stop().slideUp(300);
                        }
                        jQuery(this).removeClass('active');
                        jQuery(this).html($view_all_tags);
                        
                    }else{
                        if(jQuery($_this).find('a').hasClass('is_visible')){
                            $_this.find('.is_visible').removeClass('is_visible').addClass('is_hidden').stop().slideDown(400);
                        }
                        jQuery(this).addClass('active');
                        jQuery(this).html($hide_all_tags);
                    }
                    
                    return false;
                });
            }
        }
        <?php endif; ?>
        <?php echo snsanton_themeoption('advance_customjs','');?>
    });
    <?php
    $output = ob_get_clean();
    return $output;
}

/** 
 *	Tile for page, post
 **/
function snsanton_pagetitle(){
	// Disable title in page
	if( is_page() && function_exists('rwmb_meta') && rwmb_meta('snsanton_showtitle') == '2' ) return;
	// Show title in page, single post
	if( is_single() || is_page() || ( is_home() && get_option( 'show_on_front' ) == 'page' ) ) : ?>
		<h1 class="page-header">
             <?php the_title(); ?>
        </h1>
        
    <?php 
    // Show title for category page
    elseif ( is_category() ) : ?>
        <h1 class="page-header">
             <?php single_cat_title(); ?>
        </h1>
    <?php
    // Author
    elseif ( is_author() ) : ?>
        <h1 class="page-header">
        <?php
            printf( esc_html__( 'All posts by: %s', 'snsanton' ), get_the_author() );
        ?>
        </h1>
    <?php 
    // Tag
    elseif ( is_tag() ) : ?>
        <h1 class="page-header">
            <?php printf( esc_html__( 'Tag Archives: %s', 'snsanton' ), single_tag_title( '', false ) ); ?>
        </h1>
    <?php 
    // Search
    elseif ( is_search() ) : ?>
    <h1 class="page-header"><?php printf( esc_html__( 'Search Results for: %s', 'snsanton' ), get_search_query() ); ?></h1>
    <?php
    // Archive
    elseif ( is_archive() ) : ?>
        <h2 class="page-header">
            <?php 
            if ( class_exists('WooCommerce') && is_woocommerce() ) {
                woocommerce_page_title(); 
            }else{
                the_archive_title();
            }
            ?>
        </h2>
    <?php
    // Default
    else : ?>
        <h1 class="page-header">
          <?php the_title(); ?>
        </h1>
    <?php
	endif;
}

// Excerpt Function
if(!function_exists('snsanton_excerpt')){
    function snsanton_excerpt($limit, $afterlimit='...') {
        $limit = ($limit) ? $limit : 55 ;
        $excerpt = get_the_excerpt();
        if( $excerpt != '' ){
           $excerpt = explode(' ', strip_tags( $excerpt ), intval($limit));
        }else{
            $excerpt = explode(' ', strip_tags(get_the_content( )), intval($limit));
        }
        if ( count($excerpt) >= $limit ) {
            array_pop($excerpt);
            $excerpt = implode(" ",$excerpt).' '.$afterlimit;
        } else {
            $excerpt = implode(" ",$excerpt);
        }
        $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
        return strip_shortcodes( $excerpt );
    }
}

/*
 * Ajax page navigation
 */
function snsanton_ajax_load_next_page(){
	// Get current layout
	global $snsanton_blog_layout, $snsanton_obj;
	$snsanton_blog_layout = isset($_POST['snsanton_blog_layout']) ? esc_html($_POST['snsanton_blog_layout']) : '';
	if( $snsanton_blog_layout == '' ) $snsanton_blog_layout = $snsanton_obj->snsanton_getOption('blog_type');
	
	// Get current page
	$page = $_POST['page'];
	
	// Number of published sticky posts
	$sticky_posts = snsanton_get_sticky_posts_count();
	
	// Current query vars
	$vars = $_POST['vars'];
	
	// Convert string value into corresponding data types
	foreach ($vars as $key => $value){
		if( is_numeric($value) ) $vars[$key] = intval($value);
		if( $value == 'false' ) $vars[$key] = false;
		if( $value == 'true' ) $vars[$key] = true;
	}
	
	// Item template file 
	$template = $_POST['template'];
	
	// Return next page
	$page = intval($page) + 1;
	
	$posts_per_page = get_option('posts_per_page');
    if( $page == 2 && $vars['posts_per_page'] ){
        $offset = $vars['posts_per_page'];
    }else{
        $offset = $vars['posts_per_page'] + ($page - 2) * $posts_per_page;
    }
	
	// Get more posts per page than necessary to detect if there are more posts
	$args = array('post_status'=>'publish', 'posts_per_page'=>$posts_per_page + 1, 'offset'=>$offset);
	$args = array_merge($vars, $args);
	
	// Remove unnecessary variables
	unset($args['paged']);
	unset($args['p']);
	unset($args['page']);
	unset($args['pagename']); // This is necessary in case Posts Page is set to static page
	
	$query = new WP_Query($args);
	
	$idx = 0;
	if( $query->have_posts() ){
		while ( $query->have_posts() ){
			$query->the_post();
			$idx = $idx + 1;
			if( $idx < $posts_per_page + 1 )
				get_template_part($template, get_post_format());
		}
		
		if( $query->post_count <= $posts_per_page ){
			// There are no more posts
			// Print a flag to detect
			echo '<div id="sns-load-more-no-posts" class="no-posts"><!-- --></div>';
		}
	}else{
		// No posts found
	}
	
	/* Restore original Post Data*/
	wp_reset_postdata();
	
	die('');
}
// When the request action is "load_more", the snsanton_ajax_load_next_page() will be called
add_action('wp_ajax_load_more', 'snsanton_ajax_load_next_page');
add_action('wp_ajax_nopriv_load_more', 'snsanton_ajax_load_next_page');

// Word Limiter
function snsanton_limitwords($string, $word_limit) {
    $words = explode(' ', $string);
    return implode(' ', array_slice($words, 0, $word_limit));
}
//
if(!function_exists('snsanton_sharebox')){
    function snsanton_sharebox( $layout='',$args=array() ){
        global $post, $snsanton_obj;
        $default = array(
            'position' => 'top',
            'animation' => 'true'
            );
        $args = wp_parse_args( (array) $args, $default );
        ?>
        <div class="sns-share-box">
            <ul class="socials">
                <?php if($snsanton_obj->snsanton_getOption('show_facebook_sharebox')==1): ?>
                <li class="facebook">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr( $args['position'] ); ?>" data-animation="<?php echo esc_attr($args['animation'] ); ?>"  data-original-title="Facebook" href="http://www.facebook.com/sharer.php?s=100&p&#91;url&#93;=<?php the_permalink(); ?>&p&#91;title&#93;=<?php the_title(); ?>" target="_blank">
                        <i class="fa fa-facebook"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsanton_obj->snsanton_getOption('show_twitter_sharebox')==1): ?>
                <li class="twitter">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="Twitter" href="http://twitter.com/home?status=<?php the_title(); ?> <?php the_permalink(); ?>" target="_blank">
                        <i class="fa fa-twitter"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsanton_obj->snsanton_getOption('show_linkedin_sharebox')==1): ?>
                <li class="linkedin">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="LinkedIn" href="http://linkedin.com/shareArticle?mini=true&amp;url=<?php the_permalink(); ?>&amp;title=<?php the_title(); ?>" target="_blank">
                        <i class="fa fa-linkedin"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsanton_obj->snsanton_getOption('show_tumblr_sharebox')==1): ?>
                <li class="tumblr">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="Tumblr" href="http://www.tumblr.com/share/link?url=<?php echo urlencode(get_permalink()); ?>&amp;name=<?php echo urlencode($post->post_title); ?>&amp;description=<?php echo urlencode(get_the_excerpt()); ?>" target="_blank">
                        <i class="fa fa-tumblr"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsanton_obj->snsanton_getOption('show_gplus_sharebox')==1): ?>
                <li class="google">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="Google +1" href="https://plus.google.com/share?url=<?php the_permalink(); ?>" onclick="javascript:window.open(this.href,
            '', 'menubar=no,toolbar=no,resizable=yes,scrollbars=yes,height=600,width=600');return false;" target="_blank">
                        <i class="fa fa-google-plus"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsanton_obj->snsanton_getOption('show_pinterest_sharebox')==1): ?>
                <li class="pinterest">
                    <?php $full_image = wp_get_attachment_image_src(get_post_thumbnail_id(), 'full'); ?>
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="Pinterest" href="http://pinterest.com/pin/create/button/?url=<?php echo urlencode(get_permalink()); ?>&amp;description=<?php echo urlencode($post->post_title); ?>&amp;media=<?php echo urlencode($full_image[0]); ?>" target="_blank">
                        <i class="fa fa-pinterest"></i>
                    </a>
                </li>
                <?php endif; ?>
                <?php if($snsanton_obj->snsanton_getOption('show_email_sharebox')==1): ?>
                <li class="email">
                    <a data-toggle="tooltip" data-placement="<?php echo esc_attr($args['position']); ?>" data-animation="<?php echo esc_attr($args['animation']); ?>"  data-original-title="Email" href="mailto:?subject=<?php the_title(); ?>&amp;body=<?php the_permalink(); ?>">
                        <i class="fa fa-envelope"></i>
                    </a>
                </li>
                <?php endif; ?>
            </ul>
        </div>
        <?php
    }
}
//
if(!function_exists('snsanton_relatedpost')){
    function snsanton_relatedpost(){
        global $post;
        if($post){
        	$post_id = $post->ID;
        }else{
        	// Return if cannot find any post
        }
        
        $relate_count = snsanton_themeoption('related_num');
        $get_related_post_by = snsanton_themeoption('related_posts_by');

        $args = array(
            'post_status' => 'publish',
            'posts_per_page' => $relate_count,
            'orderby' => 'date',
            'ignore_sticky_posts' => 1,
            'post__not_in' => array ($post_id)
        );
        
        if($get_related_post_by == 'cat'){
        	$categories = wp_get_post_categories($post_id);
        	$args['category__in'] = $categories;
        }else{
        	$posttags = wp_get_post_tags($post_id);
        	
        	$array_tags = array();
        	if($posttags){
        		foreach ($posttags as $tag){
        			$tags = $tag->term_id;
        			array_push($array_tags, $tags);
        		}
        	}
        	$args['tag__in'] = $array_tags;
        }
        
        $relates = new WP_Query( $args );
        
        $template_name = '/framework/tpl/posts/related_post.php';
        if(is_file(SNSANTON_THEME_DIR.$template_name)) {
            include(SNSANTON_THEME_DIR.$template_name);
        }
        
        wp_reset_postdata();
    }
}

/*
 * Function to display number of posts.
 */
function snsanton_get_post_views($post_id){
	$count_key = 'post_views_count';
	$count = get_post_meta($post_id, $count_key, true);
	if($count == ''){
		delete_post_meta($post_id, $count_key);
		add_post_meta($post_id, $count_key, '0');
		return esc_html__('0 view', 'snsanton');
	}
	return $count. esc_html__(' View', 'snsanton');
}

/*
 * Function to count views.
 */
function snsanton_set_post_views($post_id){
	$count_key = 'post_views_count';
	$count = get_post_meta($post_id, $count_key, true);
	if($count == ''){
		$count = 0;
		delete_post_meta($post_id, $count_key);
		add_post_meta($post_id, $count_key, '0');
	}else{
		$count++;
		update_post_meta($post_id, $count_key, $count);
	}
}


function snsanton_comment($comment, $args, $depth) {
    $GLOBALS['comment'] = $comment; ?>
    <?php $add_below = ''; ?>
    <li <?php comment_class(); ?> id="comment-<?php comment_ID() ?>">
        <div class="comment-body">
        	<div class="comment-user-meta">
        		<?php echo get_avatar($comment, 70); ?>
        		<div>
        			<h4 class="comment-user"><?php echo get_comment_author_link(); ?></h4>
	            	<div class="comment-meta"><?php printf(esc_html__('%1$s at %2$s', 'snsanton'), get_comment_date(),  get_comment_time()) ?></div>
    		           <div class="reply">
                      <?php edit_comment_link(esc_html__('Edit', 'snsanton'),'  ','') ?>
                      <?php comment_reply_link(array_merge( $args, array('reply_text' => esc_html__('Reply', 'snsanton'), 'add_below' => 'comment', 'depth' => $depth, 'max_depth' => $args['max_depth'])))?>
                    </div>
                      <div class="comment-content">
                        <?php if ($comment->comment_approved == '0') : ?>
                        <p>
                            <em><?php echo esc_html__('Your comment is awaiting moderation.', 'snsanton') ?></em><br />
                        </p>
                        <?php endif; ?>
                         <?php comment_text() ?>
                       
                    </div>
                </div>

        	</div>
            
        </div>
  <?php 
}
/** 
 *	Breadcrumbs
 **/
function snsanton_breadcrumbs(){
    $template_name = '/tpl-breadcrumb.php';
	if(is_file(SNSANTON_THEME_DIR.$template_name)) {
        include(SNSANTON_THEME_DIR.$template_name);
    }
}

/*
 * Woocommerce advanced search functionlity
 */
add_action('pre_get_posts', 'snsanton_advanced_search_query', 1000);
function snsanton_advanced_search_query($query){
	if($query->is_search()) {
		// Category terms search
		if( isset($_GET['snsanton_woo_category']) && !empty($_GET['snsanton_woo_category']) ){
			$query->set('tax_query', array(array(
				'taxonomy' 	=> 'product_cat',
				'field'		=> 'slug',
				'term'		=> array($_GET['snsanton_woo_category']) )
			));
		}
	}
	return $query;
}

/* Sample data */
add_action( 'admin_enqueue_scripts', 'snsanton_importlib' );
function snsanton_importlib(){
    wp_enqueue_script('sampledata', SNSANTON_THEME_URI . '/framework/sample-data/assets/script.js', array('jquery'), '', true);
    wp_enqueue_style('sampledata-css', SNSANTON_THEME_URI . '/framework/sample-data/assets/style.css');
}
add_action( 'wp_ajax_sampledata', 'snsanton_importsampledata' );
function snsanton_importsampledata(){
    include_once(SNSANTON_THEME_DIR . '/framework/sample-data/sns-importdata.php');
    snsanton_importdata();
}

function brightness($colourstr, $steps) {
  $colourstr = str_replace('#','',$colourstr);

  $rhex = substr($colourstr,0,2);
  $ghex = substr($colourstr,2,2);
  $bhex = substr($colourstr,4,2);

  $r = hexdec($rhex);
  $g = hexdec($ghex);
  $b = hexdec($bhex);

  $r = dechex(max(0,min(255,$r + $steps)));
  $g = dechex(max(0,min(255,$g + $steps)));  
  $b = dechex(max(0,min(255,$b + $steps)));

  $r = str_pad($r,2,"0",STR_PAD_LEFT);
  $g = str_pad($g,2,"0",STR_PAD_LEFT);
  $b = str_pad($b,2,"0",STR_PAD_LEFT);

  $cor = '#'.$r.$g.$b;

  return $cor;
}



function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328660&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        ?>